{% if ssh['Match'] is defined %}
{{   match_block(ssh['Match']) -}}
{% elif __ssh_defaults['Match'] is defined and not __ssh_skip_defaults|trim|bool %}
{{   match_block(__ssh_defaults['Match']) -}}
{% endif %}
{% if ssh_Match is defined %}
{{   match_block(ssh_Match) -}}
{% endif %}
{% if ssh['Host'] is defined %}
{{   host_block(ssh['Host']) -}}
{% elif __ssh_defaults['Host'] is defined and not __ssh_skip_defaults|trim|bool %}
{{   host_block(__ssh_defaults['Host']) -}}
{% endif %}
{% if ssh_Host is defined %}
{{   host_block(ssh_Host) -}}
{% endif %}
